//
//  WAPAroundMeViewController.m
//  Wiki a picture
//
//  Created by Federico Tortora on 06/11/11.
//  Copyright (c) 2011 CocoAdvanced. All rights reserved.
//

#import "WAPAroundMeViewController.h"

@implementation WAPAroundMeViewController
@synthesize locations, locationManager,imageToUpload;

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [[self locationManager] startUpdatingLocation];
    [self setTitle:@"Select article"];
    [[[self navigationController] navigationBar] setTintColor:[UIColor colorWithRed:24.0/255 green:120.0/255 blue:52.0/255 alpha:1.0f]];
    [super viewDidLoad];
    
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [locations count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:CellIdentifier] autorelease];
    }
    
    [[cell textLabel] setBackgroundColor:[UIColor clearColor]];
    [cell setAccessoryType:UITableViewCellAccessoryDetailDisclosureButton];
    [cell setBackgroundView:[[[GradientView alloc] init] autorelease]];
    [cell setSelectedBackgroundView:[[[GradientView alloc] initGreen] autorelease]];
    
    [[cell textLabel] setText:[[locations objectAtIndex:[indexPath row]] title]];
    return cell;
}

- (void)tableView:(UITableView *)tableView accessoryButtonTappedForRowWithIndexPath:(NSIndexPath *)indexPath {
    WAPWebView * wapWebview = [[WAPWebView alloc] initWithNibName:@"WAPWebView" bundle:nil];
    [[wapWebview webView] loadRequest:[[NSURLRequest alloc] initWithURL:[NSURL URLWithString:[[locations objectAtIndex:[indexPath row]] wikipediaURL]]]];
    NSLog(@"%@",[[locations objectAtIndex:[indexPath row]] wikipediaURL] );
    [[self navigationController]pushViewController:wapWebview animated:YES];
}

/*
// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source
        [tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}
*/


#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    MBProgressHUD * hud = [[MBProgressHUD alloc] initWithView:[[self navigationController] view]];
    [[[self navigationController ]view] addSubview:hud];
    FTMediaWiki *ft = [[FTMediaWiki alloc] initWithUsername:[[NSUserDefaults standardUserDefaults] valueForKey:@"username"] andPassword:[[NSUserDefaults standardUserDefaults] valueForKey:@"username"]];
    
    [ft uploadDirectlyWithData:UIImagePNGRepresentation(imageToUpload) toPage:[[locations objectAtIndex:[indexPath row]] title]];
    [hud removeFromSuperview];
    [self dismissModalViewControllerAnimated:NO];
}


#pragma mark - Location manager

- (CLLocationManager *)locationManager {
    if (locationManager != nil) {
		return locationManager;
	}
	
	locationManager = [[CLLocationManager alloc] init];
	[locationManager setDesiredAccuracy:kCLLocationAccuracyBest];
	[locationManager setDelegate:self];
	
	return locationManager;
}

- (void)locationManager:(CLLocationManager *)manager didUpdateToLocation:(CLLocation *)newLocation fromLocation:(CLLocation *)oldLocation {
    [[self locationManager] stopUpdatingLocation];

    CLLocationCoordinate2D coordinate = [newLocation coordinate];    
    NSString *url = [NSString stringWithFormat:@"http://api.geonames.org/findNearbyWikipedia?radius=20&username=%@&lat=%f&lng=%f&lang=%@",[[NSUserDefaults standardUserDefaults] valueForKey:@"geoUsername"], coordinate.latitude, coordinate.longitude, [[NSLocale preferredLanguages] objectAtIndex:0]];
    NSError *error;
    NSDictionary *dict = [XMLReader dictionaryForXMLData:[NSData dataWithContentsOfURL:[NSURL URLWithString:url]] error:&error];
    locations = [[NSMutableArray alloc] init];
    
    for (NSDictionary * entry in [[dict valueForKey:@"geonames"] valueForKey:@"entry"]) {
        WAPGeonamesLocation *wapgl = [[WAPGeonamesLocation alloc] init];
        
        [wapgl setTitle:[[[entry valueForKey:@"title"] valueForKey:@"text"] stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]]];
        [wapgl setWikipediaURL:[[[entry valueForKey:@"wikipediaUrl"] valueForKey:@"text"] stringByTrimmingCharactersInSet:[NSCharacterSet whitespaceAndNewlineCharacterSet]]];
        [locations addObject:wapgl];
    }
    [[self tableView] reloadData];
}

- (void)locationManager:(CLLocationManager *)manager
       didFailWithError:(NSError *)error {
}

#pragma mark - Memory management

- (void)dealloc {
    [locationManager release];
    [super dealloc];
}


@end
